@@ -3,7 +3,7 @@ package App::FirefoxMultiAccountContainersUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-21'; # DATE
 our $DIST = 'App-FirefoxMultiAccountContainersUtils'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -380,7 +380,7 @@ App::FirefoxMultiAccountContainersUtils - Utilities related to Firefox Multi-Acc
 
 =head1 VERSION
 
-This document describes version 0.009 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2020-09-21.
+This document describes version 0.010 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2020-09-21.
 
 =head1 SYNOPSIS
 
@@ -657,9 +657,17 @@ feature.
 
 =head1 SEE ALSO
 
-Firefox Multi-Account Containers,
+"Firefox Multi-Account Containers" add-on,
 L<https://addons.mozilla.org/en-US/firefox/addon/multi-account-containers/>
 
+"Open external links in a container" add-on,
+L<https://addons.mozilla.org/en-US/firefox/addon/open-url-in-container/> (repo
+at L<https://github.com/honsiorovskyi/open-url-in-container/>). The add-on also
+comes with a bash launcher script:
+L<https://github.com/honsiorovskyi/open-url-in-container/blob/master/bin/launcher.sh>.
+This C<firefox-container> Perl script is a slightly enhanced version of that
+launcher script.
+
 Some other CLI utilities related to Firefox: L<App::FirefoxUtils>,
 L<App::DumpFirefoxHistory>.
 
